using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;


using Syncfusion.Windows.Forms.Grid;
using Syncfusion.XlsIO;

namespace GridDataBoundToExcel
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            MenuItem item = new MenuItem("Save As...");
            item.Click += delegate(object s, EventArgs eArgs)
            {
                SaveAsXls(gridDataBoundGrid1);
            };
            gridDataBoundGrid1.ContextMenu = new ContextMenu();
            gridDataBoundGrid1.ContextMenu.MenuItems.Add(item);

            gridDataBoundGrid1.DataSource = GetData();
            gridDataBoundGrid1.PrepareViewStyleInfo += delegate(object s, GridPrepareViewStyleInfoEventArgs eArgs) 
            {
                if (eArgs.ColIndex == 1 && eArgs.RowIndex > 0)
                {
                    eArgs.Style.BackColor = Color.LightBlue;
                }
                else if (eArgs.ColIndex == 2)
                {
                    eArgs.Style.Format = "MM/dd/yyyy";
                }
            };
        }


        public static string SaveAsXls(GridDataBoundGrid wlstpGrid)
        {
            Syncfusion.Windows.Forms.Grid.GridModel grid = wlstpGrid.Model;
            SaveFileDialog saveFileDialog = new SaveFileDialog();
            saveFileDialog.Filter = "Excel files (*.xls)|*.xls|All files (*.*)|*.*";
            saveFileDialog.FilterIndex = 1;
            saveFileDialog.RestoreDirectory = true;
            if (saveFileDialog.ShowDialog() == DialogResult.OK)
            {
                PrepareForSave(wlstpGrid);
                int workSheetCount = 1;
                ExcelEngine excelEngine = new ExcelEngine();
                IApplication excelApp = excelEngine.Excel;
                IWorkbook excelWorkbook = excelApp.Workbooks.Create(workSheetCount);
                try
                {
                    Syncfusion.GridExcelConverter.GridExcelConverterControl gecc = new Syncfusion.GridExcelConverter.GridExcelConverterControl();
                    IWorksheet sheet = excelWorkbook.Worksheets[0];
                    sheet.Name = "Sheet 1";
                    gecc.GridToExcel(grid, sheet,
                    Syncfusion.GridExcelConverter.ConverterOptions.ColumnHeaders |
                    Syncfusion.GridExcelConverter.ConverterOptions.RowHeaders |
                    Syncfusion.GridExcelConverter.ConverterOptions.Visible);
                    excelWorkbook.SaveAs(saveFileDialog.FileName, ExcelSaveType.SaveAsXLS);
                    return saveFileDialog.FileName;
                }
                catch (Syncfusion.XlsIO.Implementation.Exceptions.LockShareViolationException lsex)
                {
                    MessageBox.Show("Some other application is using this file.\r\nPlease save to a different file.", "File is being locked", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return "";
                }
                catch
                {
                    return "";
                }
                finally
                {
                    excelWorkbook.Close();
                    excelEngine.Dispose();
                }
            }
            return "";
        }

        private static void PrepareForSave(GridDataBoundGrid grid)
        {
            if (grid == null)
                return;
            foreach (GridBoundColumn col in grid.GridBoundColumns)
            {
                if (col.StyleInfo.CellValueType == typeof(DateTime))
                    col.StyleInfo.Format = "MM/dd/yyyy";
            }
        }
        private DataView GetData()
        {
            DataTable t = new DataTable();

            t.Columns.Add("Value", typeof(string));
            t.Columns.Add("Date", typeof(DateTime));

            t.Rows.Add("val 1", new DateTime(2007, 1, 1));
            t.Rows.Add("val 2", new DateTime(2007, 3, 13));
            t.Rows.Add("val 3", new DateTime(2007, 7, 30));

            t.AcceptChanges();

            DataView view = new DataView(t);
            return view;
        }




    }
}